==> zio-aws-securityhub_2.13-5.17.124.2-sources.jar: zio/aws/securityhub/model/AwsOpenSearchServiceDomainLogPublishingOption.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsOpenSearchServiceDomainLogPublishingOption(
    cloudWatchLogsLogGroupArn: Option[NonEmptyString] = None,
    enabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption = {
    import AwsOpenSearchServiceDomainLogPublishingOption.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
      .builder()
      .optionallyWith(
        cloudWatchLogsLogGroupArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.cloudWatchLogsLogGroupArn)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly =
    zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
      .wrap(buildAwsValue())
}
object AwsOpenSearchServiceDomainLogPublishingOption {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption =
      zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption(
        cloudWatchLogsLogGroupArn.map(value => value),
        enabled.map(value => value)
      )
    def cloudWatchLogsLogGroupArn: Option[NonEmptyString]
    def enabled: Option[Boolean]
    def getCloudWatchLogsLogGroupArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "cloudWatchLogsLogGroupArn",
        cloudWatchLogsLogGroupArn
      )
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ) extends zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly {
    override val cloudWatchLogsLogGroupArn: Option[NonEmptyString] = scala
      .Option(impl.cloudWatchLogsLogGroupArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val enabled: Option[Boolean] =
      scala.Option(impl.enabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ): zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-6.20.162.1-sources.jar: zio/aws/securityhub/model/AwsOpenSearchServiceDomainLogPublishingOption.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsOpenSearchServiceDomainLogPublishingOption(
    cloudWatchLogsLogGroupArn: Optional[NonEmptyString] = Optional.Absent,
    enabled: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption = {
    import AwsOpenSearchServiceDomainLogPublishingOption.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
      .builder()
      .optionallyWith(
        cloudWatchLogsLogGroupArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.cloudWatchLogsLogGroupArn)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly =
    zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
      .wrap(buildAwsValue())
}
object AwsOpenSearchServiceDomainLogPublishingOption {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption =
      zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption(
        cloudWatchLogsLogGroupArn.map(value => value),
        enabled.map(value => value)
      )
    def cloudWatchLogsLogGroupArn: Optional[NonEmptyString]
    def enabled: Optional[Boolean]
    def getCloudWatchLogsLogGroupArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "cloudWatchLogsLogGroupArn",
        cloudWatchLogsLogGroupArn
      )
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ) extends zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly {
    override val cloudWatchLogsLogGroupArn: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cloudWatchLogsLogGroupArn())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val enabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption
  ): zio.aws.securityhub.model.AwsOpenSearchServiceDomainLogPublishingOption.ReadOnly =
    new Wrapper(impl)
}
